@@ -1,8 +1,9 @@
 #! /usr/bin/perl -w
 
-# Copyright (c) 2003-2012 Henk Penning, all rights reserved.
-# penning@cs.uu.nl, http://www.cs.uu.nl/staff/henkp.html
+# Copyright (c) 2003-2013 Henk Penning, all rights reserved.
+# penning@uu.nl, http://www.staff.science.uu.nl/~penni101/
 # Version 1.1 was donated to the Apache Software Foundation 2003 Jan 28.
+#
 # Permission is hereby granted, free of charge, to any person obtaining a
 # copy of this software and associated documentation files (the "Software"),
 # to deal in the Software without restriction, including without limitation
@@ -28,7 +29,7 @@
 use strict ;
 
 our $PRG = 'mirmon' ;
-our $VER = "2.6" ;
+our $VER = "2.9" ;
 
 our $DEF_TIMEOUT = 300 ;
 our $HIST        = 14 ;
@@ -37,7 +38,7 @@ our %APA_TYPES   = () ; $APA_TYPES { $_ } ++ for qw(backup ftp http rsync) ;
 our %GET_OPTS    = () ; $GET_OPTS  { $_ } ++ for qw(all update) ;
 our $HIST_DELTA  = 24 * 60 * 60 ;
 our $APRX_DELTA  = 300 ;
-our $HOME        = 'http://www.cs.uu.nl/people/henkp/mirmon/' ;
+our $HOME        = 'http://www.staff.science.uu.nl/~penni101/mirmon/' ;
 
 package Base ; #####################################################
 
@@ -425,7 +426,7 @@ sub get_dates
     my @QUE   = () ;
     my $GET   = IO::Select -> new () ;
     my $ques  = {} ;
-    for my $col ( qw(grn red new) )
+    for my $col ( qw(new red grn xtr) )
       { $ques -> { $col } { $_ } = [] for qw(done todo) ; }
     my $max_poll = s4tim $conf -> max_poll ;
     my $min_poll = s4tim $conf -> min_poll ;
@@ -451,12 +452,13 @@ if ( Mirmon::verbose )
             my $que ;
             if ( $stat eq 'undef' ) # never probed ; new mirror ; todo
               { $col = 'new' ; $que = 'todo' ; }
+            elsif ( $conf -> get_xtr ( $mirror -> region ) )
+              { $col = 'xtr' ; $que = 'todo' ; }
             else
               { my $poll = $stat eq 'ok' ? $maxp : $minp ;
                 $col     = $stat eq 'ok' ? 'grn' : 'red' ;
                 $que     = ( aprx_le $lprb, $poll ) ? 'todo' : 'done' ;
               }
-
             push @{ $ques -> { $col } { $que } }, $mirror ;
           }
 
@@ -471,11 +473,12 @@ if ( Mirmon::verbose )
           ( @{ $ques -> { new } { todo } }
           , @{ $ques -> { red } { todo } }
           , @{ $ques -> { grn } { todo } }
+          , @{ $ques -> { xtr } { todo } }
           ) ;
       }
     else
       { die "unknown opt_get '$get'" ; }
-    
+
     if ( Mirmon::verbose ) { printf "queued %d\n\n", scalar @QUE ; }
 
     while ( @QUE )
@@ -972,7 +975,7 @@ sub gen_histogram
       { $res .= sprintf "<BR>each %s unit represents %s mirror sites.\n"
           , $units, sprintf ( "%.1f", $max / $H ) ;
       }
-    return H2 ( NAM 'age-histogram', 'age histogram' ) 
+    return H2 ( NAM 'age-histogram', 'age histogram' )
       . BQ $res ;
   }
 
@@ -1221,6 +1224,7 @@ our %CNF_defaults =
   , htm_top      => ''
   , htm_foot     => ''
   , htm_head     => ''
+  , always_get   => ''
   ) ;
 
 our @REQ_KEYS =
@@ -1235,6 +1239,12 @@ my @PUT_HGRAM  = qw(top bottom nowhere) ;
 
 eval Base -> mk_methods ( keys %CNF_KEYS, qw(root site_url) ) ;
 
+sub get_xtr
+  { my $self = shift ;
+    my $reg  = shift ;
+    scalar grep { $_ eq $reg } split ' ', $self -> always_get ;
+  }
+
 sub new
   { my $self = shift ;
     my $FILE = shift ;
@@ -1711,7 +1721,7 @@ The url as given in the mirror list.
 
 =item B<age>
 
-The mirror's timestamp found by the last succesful probe,
+The mirror's timestamp found by the last successful probe,
 or 'undef' if no probe was ever successful.
 
 =item B<last_status>
@@ -1720,7 +1730,7 @@ The status of the last probe, or 'undef' if the mirror was never probed.
 
 =item B<last_ok_probe>
 
-The timestamp of the last succesful probe or 'undef'
+The timestamp of the last successful probe or 'undef'
 if the mirror was never successfully probed.
 
 =item B<probe_history>
@@ -1808,7 +1818,9 @@ and updates the state of the mirror.
 
 =begin html
 
-<A HREF="mirmon.html">mirmon(1)</A>
+<p>
+<a href="mirmon.html">mirmon(1)</a>
+</p>
 
 =end html
 
@@ -1822,30 +1834,33 @@ mirmon(1)
 
 =begin html
 
-  &copy; 2003-2012
-  <A HREF="http://people.cs.uu.nl/henkp/">Henk P. Penning</A>,
-  <A HREF="http://www.cs.uu.nl/">Computer Science Department</A>,
-  <A HREF="http://www.uu.nl/">Utrecht University</A>
-  <BR>
-  mirmon-2.6 - Fri Mar 30 09:56:03 2012 ; henkp
+  <p>
+  &copy; 2003-2013
+  <a href="http://www.staff.science.uu.nl/~penni101/">Henk P. Penning</a>,
+  <a href="http://www.uu.nl/faculty/science/EN/">Faculty of Science</a>,
+  <a href="http://www.uu.nl/">Utrecht University</a>
+  <br />
+  mirmon-2.9 - Tue Aug 13 06:48:23 2013 ; henkp ;
+  <a href="http://validator.w3.org/check?uri=referer">verify html</a>
+  </p>
 
 =end html
 
 =begin man
 
-  (c) 2003-2012 Henk P. Penning
-  Computer Science Department, Utrecht University
-  http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
-  mirmon-2.6 - Fri Mar 30 09:56:03 2012 ; henkp
+  (c) 2003-2013 Henk P. Penning
+  Faculty of Science, Utrecht University
+  http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
+  mirmon-2.9 - Tue Aug 13 06:48:23 2013 ; henkp
 
 =end man
 
 =begin text
 
-  (c) 2003-2012 Henk P. Penning
-  Computer Science Department, Utrecht University
-  http://people.cs.uu.nl/henkp/ -- penning@cs.uu.nl
-  mirmon-2.6 - Fri Mar 30 09:56:03 2012 ; henkp
+  (c) 2003-2013 Henk P. Penning
+  Faculty of Science, Utrecht University
+  http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
+  mirmon-2.9 - Tue Aug 13 06:48:23 2013 ; henkp
 
 =end text
 
