@@ -12,7 +12,7 @@ use IO::Pipe ;
 use IO::Select ;
 use Net::hostent ;
 
-my $VERSION = Base::Version . ' - Sat Jan  5 15:09:55 2013 - henkp' ;
+my $VERSION = Base::Version . ' - Tue Aug 13 06:48:23 2013 - henkp' ;
 my $DEF_CNF = join ', ', Mirmon -> config_list ;
 my $TIMEOUT = Base::DEF_TIMEOUT ;
 
@@ -102,7 +102,7 @@ see option C<max_poll> below.
 =item B<-c> I<name>
 
 Use config file I<name>. The default list is
-  
+
   ./mirmon.conf $HOME/.mirmon.conf /etc/mirmon.conf
 
 =back
@@ -655,7 +655,7 @@ mirmon.pm(3)
   <a href="http://www.uu.nl/faculty/science/EN/">Faculty of Science</a>,
   <a href="http://www.uu.nl/">Utrecht University</a>
   <br />
-  mirmon-2.8 - Sat Jan  5 15:09:55 2013 ; henkp ;
+  mirmon-2.9 - Tue Aug 13 06:48:23 2013 ; henkp ;
   <a href="http://validator.w3.org/check?uri=referer">verify html</a>
   </p>
 
@@ -666,7 +666,7 @@ mirmon.pm(3)
   (c) 2003-2013 Henk P. Penning
   Faculty of Science, Utrecht University
   http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
-  mirmon-2.8 - Sat Jan  5 15:09:55 2013 ; henkp
+  mirmon-2.9 - Tue Aug 13 06:48:23 2013 ; henkp
 
 =end man
 
@@ -675,7 +675,7 @@ mirmon.pm(3)
   (c) 2003-2013 Henk P. Penning
   Faculty of Science, Utrecht University
   http://www.staff.science.uu.nl/~penni101/ -- penning@uu.nl
-  mirmon-2.8 - Sat Jan  5 15:09:55 2013 ; henkp
+  mirmon-2.9 - Tue Aug 13 06:48:23 2013 ; henkp
 
 =end text
 
